Coverage for audoma_api/migrations/0002_alter_examplemodel_json_and_more.py: 0%

1# Generated by Django 4.0.4 on 2022-05-10 14:09

2

3 from django.db import migrations

4

5 import audoma.django.db.fields

6

7

8 class Migration(migrations.Migration):

9

10 dependencies = [

11 ("audoma_api", "0001_initial"),

12 ]

13

14 operations = [

15 migrations.AlterField(

16 model_name="examplemodel",

17 name="json",

18 field=audoma.django.db.fields.JSONField(),

19 ),

20 migrations.AlterField(

21 model_name="examplemodel",

22 name="mac_adress",

23 field=audoma.django.db.fields.MACAddressField(integer=True),

24 ),

25 migrations.AlterField(

26 model_name="examplemodel",

27 name="money_currency",

28 field=audoma.django.db.fields.CurrencyField(

29 choices=[

30 ("AUD", "Australian Dollar"),

31 ("GBP", "British Pound"),

32 ("CNY", "Chinese Yuan"),

33 ("EUR", "Euro"),

34 ("INR", "Indian Rupee"),

35 ("JPY", "Japanese Yen"),

36 ("NZD", "New Zealand Dollar"),

37 ("CHF", "Swiss Franc"),

38 ("USD", "US Dollar"),

39 ],

40 default="XYZ",

41 max_length=3,

42 ),

43 ),

44 migrations.AlterField(

45 model_name="exampleperson",

46 name="savings_currency",

47 field=audoma.django.db.fields.CurrencyField(

48 choices=[

49 ("AUD", "Australian Dollar"),

50 ("GBP", "British Pound"),

51 ("CNY", "Chinese Yuan"),

52 ("EUR", "Euro"),

53 ("INR", "Indian Rupee"),

54 ("JPY", "Japanese Yen"),

55 ("NZD", "New Zealand Dollar"),

56 ("CHF", "Swiss Franc"),

57 ("USD", "US Dollar"),

58 ],

59 default="PLN",

60 max_length=3,

61 ),

62 ),

63 ]